@@ -141,9 +141,10 @@ class LoadBalancer:
 if __name__ == "__main__":
     from argparse import ArgumentParser
     from importlib import import_module
-    from threading import Thread
-    from sys import path
     from logging import basicConfig, INFO
+    from os import environ
+    from sys import path
+    from threading import Thread
 
     path.insert(0, ".")
 
@@ -156,6 +157,8 @@ if __name__ == "__main__":
         module = import_module(module)
         return getattr(module, symbol)
 
+    DEFAULT_WORKERS = int(environ.get("POTHEAD_WORKERS", 1))
+
     parser = ArgumentParser(description="Run WSGI app in sequential `worker` mode")
     parser.add_argument(
         "--connect",
@@ -164,7 +167,7 @@ if __name__ == "__main__":
         help="Load Balancer Hub to connect to [host:port]",
     )
     parser.add_argument(
-        "--workers", default=1, type=int, help="Number of worker Processes"
+        "--workers", default=DEFAULT_WORKERS, type=int, help="Number of worker Processes"
     )
     parser.add_argument(
         "app",
